/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: AbsConfig.java 2438 2010-02-24 16:20:30Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.controller.common;

import org.ow2.cmi.config.JmxConnectors;
import org.ow2.util.component.Components;


/**
 * @author Loris Bouzonnet
 */
public abstract class AbsConfig implements IConfig {

    /**
     * Default name for binding an instance of ClientClusterViewProvider.
     */
    private static final String DEFAULT_PROVIDER_BIND_NAME = "client_provider";

    /**
     * Default name for binding an instance of the dummy objects representing
     * registry.
     */
    private static final String DEFAULT_DUMMY_REGISTRY_BIND_NAME = "dummy_registry";

    private String clientProviderName = DEFAULT_PROVIDER_BIND_NAME;

    private String dummyRegistryName = DEFAULT_DUMMY_REGISTRY_BIND_NAME;

    /**
     * Indicates if the dummy registry is used to lookup the objects that are not clustered.
     * True by default.
     */
    private boolean dummyRegistryEnabled = true;

    /**
     * MBean domain name.
     */
    private String mbeanDomainName = "cmi";

    /**
     * MBean server name.
     */
    private String mbeanName = "CMIServer";

    private boolean adminEnabled = true;

    private boolean autoConfigureComponents;

    private String confDir;

    /**
     * List of components that have been defined.
     */
    private Components components = new Components();

    private JmxConnectors jmxConnectors;


    public String getMbeanDomainName() {
        return mbeanDomainName;
    }

    public void setMbeanDomainName(final String mbeanDomainName) {
        this.mbeanDomainName = mbeanDomainName;
    }

    public String getMbeanName() {
        return mbeanName;
    }

    public void setMbeanName(final String mbeanName) {
        this.mbeanName = mbeanName;

    }

    public void addInterceptors(final Class<?>[] interceptors) {
        // TODO Auto-generated method stub

    }

    public boolean isAdminEnabled() {
        return adminEnabled;
    }

    /**
     * @param adminEnabled the adminEnabled to set
     */
    public void setAdminEnabled(final boolean adminEnabled) {
        this.adminEnabled = adminEnabled;
    }

    public boolean isAutoConfigureComponents() {
        return autoConfigureComponents;
    }

    /**
     * @param autoConfigureComponents the autoConfigureComponents to set
     */
    public void setAutoConfigureComponents(final boolean autoConfigureComponents) {
        this.autoConfigureComponents = autoConfigureComponents;
    }

    public String getDummyRegistryName() {
        return dummyRegistryName;
    }

    public void setDummyRegistryName(final String dummyRegistryName) {
        this.dummyRegistryName = dummyRegistryName;
    }

    /**
     * @return true if the dummy registry is used to lookup the objects that are not clustered.
     */
    public boolean isDummyRegistryEnabled() {
        return dummyRegistryEnabled;
    }

    /**
     * Set if the dummy registry is used to lookup the objects that are not clustered.
     * @param dummyRegistryEnabled true if the dummy registry is used to lookup the objects that are not clustered.
     */
    public void setDummyRegistryEnabled(final boolean dummyRegistryEnabled) {
        this.dummyRegistryEnabled = dummyRegistryEnabled;
    }

    public String getClientProviderName() {
        return clientProviderName;
    }

    public void setClientProviderName(final String clientProviderName) {
        this.clientProviderName = clientProviderName;
    }

    public String getConfDir() {
        return confDir;
    }

    /**
     * @param confDir the confDir to set
     */
    public void setConfDir(final String confDir) {
        this.confDir = confDir;
    }

    /**
     * Gets the components that have been defined for this embedded server.
     * @return the components.
     */
    public final Components getComponents() {
        return this.components;
    }

    /**
     * Sets the components that needs to be launched.
     * @param components the set of components.
     */
    public final void setComponents(final Components components) {
        this.components = components;
    }

    /**
     * @return the jmxConnectors
     */
    public JmxConnectors getJmxConnectors() {
        return jmxConnectors;
    }

    /**
     * @param jmxConnectors the jmxConnectors to set
     */
    public void setJmxConnectors(final JmxConnectors jmxConnectors) {
        this.jmxConnectors = jmxConnectors;
    }
}
